@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 import click
 
 from shub.utils import job_resource_iter, get_job
@@ -12,9 +13,9 @@ the job ID, separated by forward slashes, e.g.:
 
     shub items 12345/2/15
 
-You can also provide the Dash job URL instead:
+You can also provide the Scrapinghub job URL instead:
 
-    shub items https://dash.scrapinghub.com/p/12345/job/2/15
+    shub items https://app.scrapinghub.com/p/12345/2/15
 
 You can omit the project ID if you have a default target defined in your
 scrapinghub.yml:
@@ -38,7 +39,9 @@ SHORT_HELP = "Fetch items from Scrapy Cloud"
 @click.argument('job_id')
 @click.option('-f', '--follow', help='output new items as they are scraped',
               is_flag=True)
-def cli(job_id, follow):
+@click.option('-n', '--tail', help='output last N items only', type=int)
+def cli(job_id, follow, tail):
     job = get_job(job_id)
-    for item in job_resource_iter(job, job.items.iter_json, follow=follow):
+    for item in job_resource_iter(job, job.items, output_json=True,
+                                  follow=follow, tail=tail):
         click.echo(item)
