@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 import logging
 from datetime import datetime
 
@@ -14,9 +15,9 @@ the job ID, separated by forward slashes, e.g.:
 
     shub log 12345/2/15
 
-You can also provide the Dash job URL instead:
+You can also provide the Scrapinghub job URL instead:
 
-    shub log https://dash.scrapinghub.com/p/12345/job/2/15
+    shub log https://app.scrapinghub.com/p/12345/2/15
 
 You can omit the project ID if you have a default target defined in your
 scrapinghub.yml:
@@ -40,14 +41,18 @@ SHORT_HELP = "Fetch log from Scrapy Cloud"
 @click.argument('job_id')
 @click.option('-f', '--follow', help='output new log entries as they are '
               'produced', is_flag=True)
-def cli(job_id, follow):
+@click.option('-n', '--tail', help='output last N log entries only', type=int)
+@click.option('--json', 'json_', help='output log entries in JSON', is_flag=True, default=False)
+def cli(job_id, follow, tail, json_):
     job = get_job(job_id)
-    for item in job_resource_iter(job, job.logs.iter_values, follow=follow,
-                                  key_func=lambda item: item['_key']):
-        click.echo(
-            "{} {} {}".format(
-                datetime.utcfromtimestamp(item['time']/1000),
-                logging.getLevelName(int(item['level'])),
-                item['message']
+    for item in job_resource_iter(job, job.logs, follow=follow, tail=tail, output_json=json_):
+        if json_:
+            click.echo(item)
+        else:
+            click.echo(
+                u"{} {} {}".format(
+                    datetime.utcfromtimestamp(item['time']/1000),
+                    logging.getLevelName(int(item['level'])),
+                    item['message']
+                )
             )
-        )
